@@ -1,4 +1,4 @@
-/* $Id: cpu.h,v 1.29 2005/01/03 09:17:44 bdejean Exp $ */
+/* $Id: cpu.h,v 1.30 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -80,7 +80,7 @@ struct _glibtop_cpu
 		xcpu_flags;	                /* GLIBTOP_XCPU_IDLE		*/
 };
 
-#define glibtop_get_cpu(cpu)	glibtop_get_cpu_l(glibtop_global_server, cpu)
+void glibtop_get_cpu(glibtop_cpu *buf);
 
 #if GLIBTOP_SUID_CPU
 #define glibtop_get_cpu_r	glibtop_get_cpu_p
