@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.23 2005/03/27 14:30:30 bdejean Exp $ */
+/* $Id: uptime.c,v 1.24 2005/07/05 23:05:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -57,7 +57,7 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 
 	buf->uptime   = g_ascii_strtod (buffer, &p);
 	buf->idletime = g_ascii_strtod (p, &p);
-	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
+	buf->boot_time = get_boot_time(server);
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
